@@ -14,14 +14,14 @@
 #'
 #' @concept prepare
 #' @export
-redist.find.target <- function(tgt_min, group_pop, total_pop, ndists, nmmd){
-  totpop <- sum(total_pop)
-  targetpop <- totpop/ndists
-  tmm <- nmmd*tgt_min*targetpop
-  totgroup <- sum(group_pop)
-  tgt_other <- (totgroup - tmm)/((ndists-nmmd)*targetpop)
-  #(sum(group_pop) - nmmd*tgt_min*targetpop)/((ndists-nmmd)*sum(total_pop)/ndists)
-  return(c(tgt_other = tgt_other))
+redist.find.target <- function(tgt_min, group_pop, total_pop, ndists, nmmd) {
+    totpop <- sum(total_pop)
+    targetpop <- totpop/ndists
+    tmm <- nmmd*tgt_min*targetpop
+    totgroup <- sum(group_pop)
+    tgt_other <- (totgroup - tmm)/((ndists - nmmd)*targetpop)
+    # (sum(group_pop) - nmmd*tgt_min*targetpop)/((ndists-nmmd)*sum(total_pop)/ndists)
+    return(c(tgt_other = tgt_other))
 }
 
 #' Create Constraints for SMC
@@ -39,24 +39,24 @@ redist.find.target <- function(tgt_min, group_pop, total_pop, ndists, nmmd){
 #'
 #' @concept prepare
 #' @export
-redist.constraint.helper <- function(constraints = 'vra', tgt_min = 0.55,
+redist.constraint.helper <- function(constraints = "vra", tgt_min = 0.55,
                                      group_pop, total_pop, ndists, nmmd,
-                                     strength_vra = 2500, pow_vra = 1.5){
+                                     strength_vra = 2500, pow_vra = 1.5) {
+    .Deprecated("redist_constr")
 
+    ret <- list()
 
-  ret <- list()
+    if ("vra" %in% constraints) {
+        tgt_other <- redist.find.target(tgt_min, group_pop, total_pop, ndists, nmmd)
 
-  if('vra' %in% constraints){
-    tgt_other <- redist.find.target(tgt_min, group_pop, total_pop, ndists, nmmd)
+        ret[["vra"]] <- list(strength = strength_vra,
+            min_pop = group_pop,
+            tgt_vra_min = tgt_min,
+            tgt_vra_other = tgt_other,
+            pow_vra = pow_vra)
 
-    ret['vra'] <- list(strength = strength_vra,
-                       min_pop = group_pop,
-                       tgt_vra_min = tgt_min,
-                       tgt_vra_other = tgt_other,
-                       pow_vra = 1.5)
-
-  }
-  return(ret)
+    }
+    ret
 }
 
-globalVariables(c('vra'))
+globalVariables(c("vra"))
