@@ -10,27 +10,24 @@
 #' @export
 #'
 #' @examples
-#' cds <- matrix(c(rep(c(4L,5L,2L,1L,3L),5),
-#' rep(c(5L,4L,3L,2L,1L),2), rep(c(4L,5L,2L,1L,3L),3)), nrow = 25)
+#' cds <- matrix(c(rep(c(4L, 5L, 2L, 1L, 3L), 5),
+#'     rep(c(5L, 4L, 3L, 2L, 1L), 2), rep(c(4L, 5L, 2L, 1L, 3L), 3)), nrow = 25)
 #' redist.reorder(cds)
-#' 
-redist.reorder <- function(plans){
-  # Check inputs
-  if(missing(plans)){
-    stop('"plans" is required.')
-  }
-  if(any(class(plans)%in% c('numeric', 'integer'))){
-    plans <- as.matrix(plans)
-  }
-  if(!('matrix' %in% class(plans))){
-    stop('Please provide "plans" as a matrix.')
-  }
+#'
+redist.reorder <- function(plans) {
+    # Check inputs
+    if (!is.matrix(plans)) {
+        if (is.numeric(plans)) {
+            plans <- as.matrix(plans, )
+        } else {
+            cli_abort("{.arg plans} must be a matrix or integer vector.")
+        }
+    }
 
-  # Prep objects for Rcpp
-  nd <- length(unique(plans[,1]))
+    # Prep objects for Rcpp
+    nd <- length(unique(plans[, 1]))
 
-  # reindex!
-  return(reindex(dm = plans, nd = nd))
+    reindex(dm = plans, nd = nd)
 }
 
 
@@ -48,22 +45,21 @@ redist.reorder <- function(plans){
 #' data(fl25_enum)
 #' plan <- fl25_enum$plans[, 5118]
 #' # Subset based on something:
-#' plan <- plan[plan!=2]
+#' plan <- plan[plan != 2]
 #' plan <- redist.sink.plan(plan)
 #' # Now plan can be used with redist.flip()
 #' plan
 #'
-#'
-redist.sink.plan <- function(plan){
-  if(class(plan) %in% c('character', 'numeric','integer')){
-    uc <- unique(sort(plan))
-    plan_id <- rep(0, length(plan))
-    for(i in 1:length(plan)){
-      plan_id[i] <- which(uc == plan[i])
+redist.sink.plan <- function(plan) {
+    if (is.character(plan) || is.numeric(plan)) {
+        uc <- unique(sort(plan))
+        plan_id <- rep(0, length(plan))
+        for (i in 1:length(plan)) {
+            plan_id[i] <- which(uc == plan[i])
+        }
+    } else {
+        stop('Please provide "plan" as a  numeric or integer vector.')
     }
-  } else{
-    stop('Please provide "plan" as a  numeric or integer vector.')
-  }
 
-  return(plan_id)
+    plan_id
 }
